@@ -28,7 +28,6 @@
 # include "config.h"
 #endif
 #include "algorithms.h"
-#include "binreloc.h"
 #include <cassert>
 #include <cstdio>
 #include <cstdlib> // for free(3)
@@ -40,6 +39,9 @@
 # include <windows.h>
 # include <shlobj.h>
 # undef ERROR
+#else
+# include <sys/stat.h>
+# include <string.h> // for memset(3)
 #endif // OS_WIN32
 
 using namespace std;
@@ -161,39 +163,41 @@ std::string algorithms_get_bankdata_dir()
    std::string prefix(accnum_get_prefix());
    pkgdatadir = prefix + "\\share\\ktoblzcheck";
 #else // OS_WIN32
-   char *datadir = br_find_data_dir(0);
-   if (datadir)
-   {
-      pkgdatadir = std::string(datadir) + std::string("/ktoblzcheck");
-      free (datadir);
-   } else
-   {
-      pkgdatadir = BANKDATA_PATH;
+   const char *xdg_data_dirs = getenv("XDG_DATA_DIRS");
+   std::string datadirs = xdg_data_dirs ? xdg_data_dirs : "";
+   if (!datadirs.empty()) {
+     struct stat stat_buf;
+     memset (&stat_buf, 0, sizeof(stat_buf));
+     const char delim = ':';
+     size_t index = datadirs.find(delim);
+     size_t previous = 0;
+     const std::string dirname("/ktoblzcheck");
+     if (index == std::string::npos)
+       pkgdatadir = datadirs;
+     else while (index != std::string::npos) {
+	 pkgdatadir = datadirs.substr(previous, index - previous) + dirname;
+	 int result = stat(pkgdatadir.c_str(), &stat_buf);
+	 if (result == 0)
+	   break;
+	 pkgdatadir.clear();
+	 previous = index + 1;
+	 index = datadirs.find(delim, previous);
+       }
+     if (pkgdatadir.empty()) {
+	 pkgdatadir = datadirs.substr(previous) + dirname;
+	 int result = stat(pkgdatadir.c_str(), &stat_buf);
+	 if (result != 0)
+	   pkgdatadir.clear();
+     }
    }
+# ifdef BANKDATA_PATH
+   if (pkgdatadir.empty())
+      pkgdatadir = BANKDATA_PATH;
+# endif // BANKDATA_PATH
 #endif // OS_WIN32
    return pkgdatadir;
 }
 
-
-static bool ktoblzcheck_binreloc_initialized = false;
-bool algorithms_init_binreloc()
-{
-   if (!ktoblzcheck_binreloc_initialized)
-   {
-      BrInitError br_error;
-
-      /* Init binreloc. Note: It is not totally clear whether the correct
-	 function might still be br_init() instead of br_init_lib(). */
-      if (!br_init_lib(&br_error)) {
-	 /* DBG_INFO(GWEN_LOGDOMAIN, "Error on br_init: %d\n", br_error); */
-	 ktoblzcheck_binreloc_initialized = false;
-      }
-      else
-	 ktoblzcheck_binreloc_initialized = true;
-   }
-   return ktoblzcheck_binreloc_initialized;
-}
-
 // ////////////////////
 
 AccountNumberCheck::Result
