@@ -646,7 +646,10 @@ AccountNumberCheck::Result method_65(const int *account, int *weight) {
     return algo01(10, weight, true, 8, account);
 }
 // Added by Jens Gecius, validated with five test accountIDs
+// method 66 was changed for due-date 2014-03-03
 AccountNumberCheck::Result method_66(const int *account, int *weight) {
+    if (9 == account[1])
+	return AccountNumberCheck::OK;		// Ausnahme "method09"
     if (0 != account[0])
 	return AccountNumberCheck::ERROR;
     number2Array("700654320", weight);
@@ -999,6 +1002,7 @@ AccountNumberCheck::Result method_89(const int *account, int *weight) {
     number2Array("987654320", weight); weight[0] = 10;
     return algo01(11, weight, false, 10, account);
 }
+// method 90 was changed for due-date 2014-09-08
 AccountNumberCheck::Result method_90(const int *account, int *weight) {
     // variant a
     number2Array("0007654320", weight);
@@ -1023,6 +1027,11 @@ AccountNumberCheck::Result method_90(const int *account, int *weight) {
     if (AccountNumberCheck::OK == algo01(10, weight, false, 10, account))
 	return AccountNumberCheck::OK;
 
+    // Methode G
+    number2Array("0001212120", weight);
+    if (AccountNumberCheck::OK == algo01(7, weight, false, 10, account))
+	return AccountNumberCheck::OK;
+
     // non-customer-accounts
     number2Array("0087654320", weight);
     return algo01(11, weight, false, 10, account);
@@ -1638,6 +1647,22 @@ AccountNumberCheck::Result method_E0(const int *account, int *weight) {
     return AccountNumberCheck::ERROR;
 }
 
+// new method E1 valid from 2013-12-09
+AccountNumberCheck::Result method_E1(const int *account, int *weight) {
+    int account_e1[10];
+    int i;
+    for (i=0; i<9; i++)
+        account_e1[i] = 48 + account[i]; // Umwandlung exklusiv Pruefziffer
+    account_e1[9] = account[9];
+    number2Array("9:;6543210", weight);  // bad Hack: ASCII-Conversation ':' -> 10, ';' -> 11
+    int tmp = algo03(11, weight, false, account_e1, 0, 9);
+    if (10 == tmp)
+	return AccountNumberCheck::ERROR;
+    if  (tmp == account[9])
+	return AccountNumberCheck::OK;
+    return AccountNumberCheck::ERROR;
+}
+
 struct method_func_s {
     const char *str;
     AccountNumberCheck::MethodFunc func;
@@ -1780,6 +1805,7 @@ const struct method_func_s cb_funcs[] = {
   { "D8", method_D8},
   { "D9", method_D9},
   { "E0", method_E0},
+  { "E1", method_E1},
   { 0, 0} // Important: The array has to end with the {0,0} entry,
 	  // otherwise initMethodMap() will runaway and crash!
 };
